==========================
Python Text Metric Package
==========================

.. image:: https://img.shields.io/pypi/v/textmetric.svg
        :target: https://pypi.python.org/pypi/textmetric

.. image:: https://img.shields.io/travis/sfischer13/python-textmetric.svg
        :target: https://travis-ci.org/sfischer13/python-textmetric


Python implementations of common text metric algorithms.
